@@ -123,11 +123,12 @@ use File::Glob qw(:case);
 %Modules = (
 
     'Archive::Tar' => {
-        'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.32.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.36.tar.gz',
         'FILES'        => q[cpan/Archive-Tar],
         'BUGS'         => 'bug-archive-tar@rt.cpan.org',
         'EXCLUDED'     => [
             qw(t/07_ptardiff.t),
+            qr{t/src/(long|short)/foo.txz},
         ],
     },
 
@@ -137,11 +138,12 @@ use File::Glob qw(:case);
     },
 
     'autodie' => {
-        'DISTRIBUTION' => 'PJF/autodie-2.29.tar.gz',
+        'DISTRIBUTION' => 'TODDR/autodie-2.32.tar.gz',
         'FILES'        => q[cpan/autodie],
         'EXCLUDED'     => [
             qr{benchmarks},
             qr{README\.md},
+            qr{^xt/},
             # All these tests depend upon external
             # modules that don't exist when we're
             # building the core.  Hence, they can
@@ -157,19 +159,9 @@ use File::Glob qw(:case);
                 t/release-pod-syntax.t
                 t/socket.t
                 t/system.t
+                t/no-all.t
                 )
         ],
-        'CUSTOMIZED'   => [
-	    # CPAN RT 105344
-	    't/mkdir.t',
-	    # smartmatch changes
-	    'lib/autodie/exception.pm',
-	    'lib/autodie/hints.pm',
-	    't/exceptions.t',
-	    't/lib/Hints_pod_examples.pm',
-            # CPAN RT#127762
-            't/recv.t',
-        ],
     },
 
     'AutoLoader' => {
@@ -207,7 +199,7 @@ use File::Glob qw(:case);
     },
 
     'Compress::Raw::Bzip2' => {
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.087.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.093.tar.gz',
         'FILES'        => q[cpan/Compress-Raw-Bzip2],
         'EXCLUDED'     => [
             qr{^t/Test/},
@@ -219,7 +211,7 @@ use File::Glob qw(:case);
     },
 
     'Compress::Raw::Zlib' => {
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.087.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.093.tar.gz',
         'FILES'    => q[cpan/Compress-Raw-Zlib],
         'EXCLUDED' => [
             qr{^examples/},
@@ -254,7 +246,7 @@ use File::Glob qw(:case);
     },
 
     'CPAN' => {
-        'DISTRIBUTION' => 'ANDK/CPAN-2.27-TRIAL2.tar.gz',
+        'DISTRIBUTION' => 'ANDK/CPAN-2.27.tar.gz',
         'FILES'        => q[cpan/CPAN],
         'EXCLUDED'     => [
             qr{^distroprefs/},
@@ -333,12 +325,13 @@ use File::Glob qw(:case);
     },
 
     'DB_File' => {
-        'DISTRIBUTION' => 'PMQS/DB_File-1.852.tar.gz',
+        'DISTRIBUTION' => 'PMQS/DB_File-1.853.tar.gz',
         'FILES'        => q[cpan/DB_File],
         'EXCLUDED'     => [
             qr{^patches/},
             qr{^t/meta},
             qw( t/pod.t
+                t/000prereq.t
                 fallback.h
                 fallback.xs
                 ),
@@ -346,7 +339,7 @@ use File::Glob qw(:case);
     },
 
     'Devel::PPPort' => {
-        'DISTRIBUTION' => 'ATOOMIC/Devel-PPPort-3.54.tar.gz',
+        'DISTRIBUTION' => 'ATOOMIC/Devel-PPPort-3.57.tar.gz',
         'FILES'        => q[dist/Devel-PPPort],
         'EXCLUDED'     => [
             'PPPort.pm',    # we use PPPort_pm.PL instead
@@ -398,8 +391,13 @@ use File::Glob qw(:case);
     },
 
     'Encode' => {
-        'DISTRIBUTION' => 'DANKOGAI/Encode-3.01.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-3.02.tar.gz',
         'FILES'        => q[cpan/Encode],
+        'EXCLUDED'     => [
+            qw( t/whatwg-aliases.json
+                t/whatwg-aliases.t
+                ),
+        ],
     },
 
     'encoding::warnings' => {
@@ -428,7 +426,7 @@ use File::Glob qw(:case);
     },
 
     'Exporter' => {
-        'DISTRIBUTION' => 'TODDR/Exporter-5.73.tar.gz',
+        'DISTRIBUTION' => 'TODDR/Exporter-5.74.tar.gz',
         'FILES'        => q[dist/Exporter],
         'EXCLUDED' => [
             qw( t/pod.t
@@ -438,7 +436,7 @@ use File::Glob qw(:case);
     },
 
     'ExtUtils::CBuilder' => {
-        'DISTRIBUTION' => 'AMBS/ExtUtils-CBuilder-0.280231.tar.gz',
+        'DISTRIBUTION' => 'AMBS/ExtUtils-CBuilder-0.280234.tar.gz',
         'FILES'        => q[dist/ExtUtils-CBuilder],
         'EXCLUDED'     => [
             qw(README.mkdn),
@@ -473,7 +471,7 @@ use File::Glob qw(:case);
     },
 
     'ExtUtils::MakeMaker' => {
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.38.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.44.tar.gz',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
             qr{^t/lib/Test/},
@@ -578,6 +576,11 @@ use File::Glob qw(:case);
         ],
     },
 
+    'FindBin' => {
+        'DISTRIBUTION' => 'XSAWYERX/FindBin-0.000.tar.gz',
+        'FILES'        => q[dist/FindBin],
+    },
+
     'Getopt::Long' => {
         'DISTRIBUTION' => 'JV/Getopt-Long-2.51.tar.gz',
         'FILES'        => q[cpan/Getopt-Long],
@@ -620,13 +623,13 @@ use File::Glob qw(:case);
     },
 
     'IO' => {
-        'DISTRIBUTION' => 'TODDR/IO-1.39.tar.gz',
+        'DISTRIBUTION' => 'TODDR/IO-1.42.tar.gz',
         'FILES'        => q[dist/IO/],
         'EXCLUDED'     => ['t/test.pl'],
     },
 
     'IO-Compress' => {
-        'DISTRIBUTION' => 'PMQS/IO-Compress-2.087.tar.gz',
+        'DISTRIBUTION' => 'PMQS/IO-Compress-2.093.tar.gz',
         'FILES'        => q[cpan/IO-Compress],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -697,7 +700,7 @@ use File::Glob qw(:case);
     },
 
     'Locale::Maketext' => {
-        'DISTRIBUTION' => 'TODDR/Locale-Maketext-1.28.tar.gz',
+        'DISTRIBUTION' => 'TODDR/Locale-Maketext-1.29.tar.gz',
         'FILES'        => q[dist/Locale-Maketext],
         'EXCLUDED'     => [
             qw(
@@ -718,7 +721,7 @@ use File::Glob qw(:case);
     },
 
     'Math::BigInt' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999817.tar.gz',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-1.999818.tar.gz',
         'FILES'        => q[cpan/Math-BigInt],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -728,14 +731,6 @@ use File::Glob qw(:case);
                 t/01load.t
                 ),
         ],
-        # CPAN RT 130736
-        'CUSTOMIZED'   => [
-            'lib/Math/BigFloat.pm',
-            'lib/Math/BigInt.pm',
-            'lib/Math/BigInt/Calc.pm',
-            'lib/Math/BigInt/Lib.pm',
-            'lib/Math-BigInt/t/calling.t'
-        ],
     },
 
     'Math::BigInt::FastCalc' => {
@@ -805,7 +800,7 @@ use File::Glob qw(:case);
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20190920.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20200120.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -815,7 +810,7 @@ use File::Glob qw(:case);
     },
 
     'Module::Load::Conditional' => {
-        'DISTRIBUTION' => 'BINGOS/Module-Load-Conditional-0.68.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-Load-Conditional-0.70.tar.gz',
         'FILES'        => q[cpan/Module-Load-Conditional],
     },
 
@@ -836,7 +831,7 @@ use File::Glob qw(:case);
     },
 
     'Net::Ping' => {
-        'DISTRIBUTION' => 'RURBAN/Net-Ping-2.71.tar.gz',
+        'DISTRIBUTION' => 'RURBAN/Net-Ping-2.72.tar.gz',
         'FILES'        => q[dist/Net-Ping],
         'EXCLUDED'     => [
             qw(README.md.PL),
@@ -859,7 +854,7 @@ use File::Glob qw(:case);
     },
 
     'parent' => {
-        'DISTRIBUTION' => 'CORION/parent-0.237.tar.gz',
+        'DISTRIBUTION' => 'CORION/parent-0.238.tar.gz',
         'FILES'        => q[cpan/parent],
         'EXCLUDED'     => [
             qr{^xt}
@@ -882,7 +877,7 @@ use File::Glob qw(:case);
     },
 
     'perlfaq' => {
-        'DISTRIBUTION' => 'ETHER/perlfaq-5.20190126.tar.gz',
+        'DISTRIBUTION' => 'ETHER/perlfaq-5.20200125.tar.gz',
         'FILES'        => q[cpan/perlfaq],
         'EXCLUDED'     => [ qr/^inc/, qr/^xt/, qr{^t/00-} ],
     },
@@ -933,7 +928,7 @@ use File::Glob qw(:case);
     },
 
     'Pod::Simple' => {
-        'DISTRIBUTION' => 'KHW/Pod-Simple-3.39.tar.gz',
+        'DISTRIBUTION' => 'KHW/Pod-Simple-3.40.tar.gz',
         'FILES'        => q[cpan/Pod-Simple],
     },
 
@@ -946,7 +941,7 @@ use File::Glob qw(:case);
     },
 
     'podlators' => {
-        'DISTRIBUTION' => 'RRA/podlators-4.12.tar.gz',
+        'DISTRIBUTION' => 'RRA/podlators-4.14.tar.gz',
         'FILES'        => q[cpan/podlators pod/perlpodstyle.pod],
         'EXCLUDED'     => [
             qr{^docs/metadata/},
@@ -965,7 +960,7 @@ use File::Glob qw(:case);
     },
 
     'Scalar::Util' => {
-        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.52.tar.gz',
+        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.53.tar.gz',
         'FILES'        => q[cpan/Scalar-List-Utils],
     },
 
@@ -994,7 +989,7 @@ use File::Glob qw(:case);
     },
 
     'Sys::Syslog' => {
-        'DISTRIBUTION' => 'SAPER/Sys-Syslog-0.35.tar.gz',
+        'DISTRIBUTION' => 'SAPER/Sys-Syslog-0.36.tar.gz',
         'FILES'        => q[cpan/Sys-Syslog],
         'EXCLUDED'     => [
             qr{^eg/},
@@ -1011,7 +1006,7 @@ use File::Glob qw(:case);
     },
 
     'Term::ANSIColor' => {
-        'DISTRIBUTION' => 'RRA/Term-ANSIColor-4.06.tar.gz',
+        'DISTRIBUTION' => 'RRA/Term-ANSIColor-5.01.tar.gz',
         'FILES'        => q[cpan/Term-ANSIColor],
         'EXCLUDED'     => [
             qr{^docs/},
@@ -1062,7 +1057,7 @@ use File::Glob qw(:case);
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302168.tar.gz',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302171.tar.gz',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1164,7 +1159,7 @@ use File::Glob qw(:case);
     },
 
     'Tie::File' => {
-        'DISTRIBUTION' => 'TODDR/Tie-File-1.00.tar.gz',
+        'DISTRIBUTION' => 'TODDR/Tie-File-1.05.tar.gz',
         'FILES'        => q[dist/Tie-File],
     },
 
@@ -1273,6 +1268,12 @@ use File::Glob qw(:case);
         'EXCLUDED'     => [
             qr{^ex/},
         ],
+        # https://rt.cpan.org/Ticket/Display.html?id=127837
+        'CUSTOMIZED'   => [
+            qw( File.pm
+                File.xs
+                ),
+        ],
     },
 
     'XSLoader' => {
@@ -1363,7 +1364,6 @@ use File::Glob qw(:case);
                 lib/File/Copy.{pm,t}
                 lib/File/stat{.pm,.t,-7896.t}
                 lib/FileHandle.{pm,t}
-                lib/FindBin.{pm,t}
                 lib/Getopt/Std.{pm,t}
                 lib/Internals.pod
                 lib/Internals.t
@@ -1425,7 +1425,6 @@ use File::Glob qw(:case);
                 lib/subs.{pm,t}
                 lib/unicore/
                 lib/utf8.{pm,t}
-                lib/utf8_heavy.pl
                 lib/vars{.pm,.t,_carp.t}
                 lib/vmsish.{pm,t}
                 ],
