@@ -330,6 +330,8 @@ sub pods_to_install {
     # manpages not to be installed
     my %do_not_install = map { ($_ => 1) }
         qw(Pod::Functions XS::APItest XS::Typemap);
+    $do_not_install{"ExtUtils::XSSymSet"} = 1
+        unless $^O eq "VMS";
 
     my (%done, %found);
 
@@ -403,7 +405,7 @@ sub __prime_state {
     my $filename = "pod/$source";
     my $contents = slurp_or_die($filename);
     my @want =
-        $contents =~ /perldelta - what is new for perl v(5)\.(\d+)\.(\d+)\n/;
+        $contents =~ /perldelta - what is new for perl v(5)\.(\d+)\.(\d+)\r?\n/;
     die "Can't extract version from $filename" unless @want;
     my $delta_leaf = join '', 'perl', @want, 'delta';
     $state{delta_target} = "$delta_leaf.pod";
@@ -547,7 +549,7 @@ Hash reference; each element provides either a list or a lookup table for
 information about various types of POD files.
 
   'aux'             => [ # utility programs like
-                            'h2xs' and 'perlbug' ]
+                            'h2xs' and 'perldoc' ]
   'generated'       => { # lookup table for generated POD files
                             like 'perlapi.pod' }
   'ignore'          => { # lookup table for files to be ignored }
@@ -665,9 +667,4 @@ sub get_pod_metadata {
 
 1;
 
-# Local variables:
-# cperl-indent-level: 4
-# indent-tabs-mode: nil
-# End:
-#
 # ex: set ts=8 sts=4 sw=4 et:
