@@ -160,7 +160,7 @@ case `$cc -v 2>&1`"" in
 	    ccversion=`what $cc_found | awk '/Compiler/{print $2}/Itanium/{print $6,$7}/for Integrity/{print $6,$7}'`
 	    case "$ccflags" in
                "-Ae "*) ;;
-		*)  ccflags="-Ae $cc_cppflags"
+		*)  ccflags="-Ae -Wp,-H65000 $cc_cppflags"
 		    # +vnocompatwarnings not known in 10.10 and older
 		    if [ $xxOsRev -ge 1020 ]; then
 			ccflags="$ccflags -Wl,+vnocompatwarnings"
@@ -486,7 +486,7 @@ case "$ccisgcc" in
 			# > cc --version
 			# cc: HP C/aC++ B3910B A.06.15 [May 16 2007]
 			# Has optimizing problems with +O2 for blead (5.17.4),
-			# see https://rt.perl.org:443/rt3/Ticket/Display.html?id=103668.
+			# see https://github.com/Perl/perl5/issues/11748.
 			#
 			# +O2 +Onolimit +Onoprocelim  +Ostore_ordering \
 			# +Onolibcalls=strcmp
