@@ -73,7 +73,7 @@ print $h <<EOF;
  */
 
 #ifndef PERL_REENTR_API
-# if defined(PERL_CORE) || defined(PERL_EXT)
+# if defined(PERL_CORE) || defined(PERL_EXT) || defined(PERL_REENTRANT)
 #  define PERL_REENTR_API 1
 # else
 #  define PERL_REENTR_API 0
@@ -855,10 +855,10 @@ Perl_reentrant_retry(const char *f, ...)
 		    p0    = va_arg(ap, void *);
 		    asize = va_arg(ap, size_t);
 		    anint  = va_arg(ap, int);
-		    retptr = gethostbyaddr(p0, asize, anint); break;
+		    retptr = gethostbyaddr((Netdb_host_t) p0, (Netdb_hlen_t) asize, anint); break;
 	        case OP_GHBYNAME:
 		    p0 = va_arg(ap, void *);
-		    retptr = gethostbyname((char *)p0); break;
+		    retptr = gethostbyname((Netdb_name_t) p0); break;
 	        case OP_GHOSTENT:
 		    retptr = gethostent(); break;
 	        default:
